slepc-3.18.0 2022-10-01
Report Typos and Errors

# DSGSVDGetDimensions

Returns the number of columns and rows for a DSGSVD.

### Synopsis

    #include "slepcds.h"
    PetscErrorCode DSGSVDGetDimensions(DS ds,PetscInt *m,PetscInt *p)

Not collective

### Input Parameter

| ds | - the direct solver context

### Output Parameters

| m | - the number of columns
| p | - the number of rows for the second matrix (B)

### See Also

DSGSVDSetDimensions()

### Level

intermediate

### Location

src/sys/classes/ds/impls/gsvd/dsgsvd.c
Index of all DS routines
Table of Contents for all manual pages
Index of all manual pages